package net.wanji.databus.entity.identity.identity;

import net.wanji.common.framework.domain.TrackableEntity;
import net.wanji.common.framework.rest.ValidationGroups;
import net.wanji.databus.entity.identity.logcenter.OnlineUser;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import java.util.Date;
import java.util.List;

/**
 * @author wanji
 * @date 2019/3/5
 */
@Getter
@Setter
@ApiModel(value = "User", description = "用户")
public class User extends TrackableEntity {

    @ApiModelProperty(value = "用户姓名", required = true)
    @NotBlank(message = "名称不能为空",groups = {ValidationGroups.Create.class})
    private String name;

    @ApiModelProperty(value = "登录名", required = true)
    @NotBlank(message = "登录名不能为空",groups = {ValidationGroups.Create.class})
    private String username;

    @ApiModelProperty(value = "盐")
    private String salt;

    @ApiModelProperty(value = "用户密码", required = true)
    @NotBlank(groups = {ValidationGroups.Create.class})
    private String password;

    @ApiModelProperty(value = "行政区划编码")
    private String adCode;

    @ApiModelProperty(value = "用户角色")
    private String role;

    @ApiModelProperty(value = "用户电话")
    private String phone;

    @ApiModelProperty(value = "用户生日")
    @JsonFormat(pattern = "yyyy-MM-dd" )
    private Date birthday;

    @ApiModelProperty(value = "邮箱")
    @Email(groups = {ValidationGroups.Create.class})
    private String email;

    @ApiModelProperty(value = "用户性别")
    private String gender;

    @ApiModelProperty(value = "用户状态", notes = "enable/disable")
    private String status;

    @ApiModelProperty(value = "登录用户的token信息")
    private String token;

    @ApiModelProperty(value = "用户头像的URL地址")
    private String url;

    private List<OnlineUser> userOnlineInfo;

    public String getCredentialsSalt() {
        return username + salt + salt;
    }

    public static User newInstance() {
        return new User();
    }

}

